@@ -30,7 +30,7 @@
 #ifndef _GNUstep_H_GSTable
 #define _GNUstep_H_GSTable
 
-#include <AppKit/NSView.h>
+#import <AppKit/NSView.h>
 
 /** 
   <unit>
@@ -171,6 +171,7 @@
   </section>
   </unit>
 */
+APPKIT_EXPORT_CLASS
 @interface GSTable: NSView
 {
   int _numberOfRows;
