@@ -29,7 +29,7 @@
 
 #ifndef _GNUstep_H_NSAttributedString
 #define _GNUstep_H_NSAttributedString
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #if OS_API_VERSION(GS_API_MACOSX, GS_API_LATEST)
 
@@ -39,7 +39,6 @@
 // for NSWritingDirection
 #import <AppKit/NSParagraphStyle.h>
 #import <AppKit/NSText.h>
-#import <AppKit/AppKitDefines.h>
 
 @class NSTextAttachment;
 @class NSFileWrapper;
@@ -70,6 +69,7 @@ APPKIT_EXPORT NSString *NSObliquenessAttributeName;
 APPKIT_EXPORT NSString *NSParagraphStyleAttributeName;
 APPKIT_EXPORT NSString *NSShadowAttributeName;
 APPKIT_EXPORT NSString *NSStrikethroughColorAttributeName;
+APPKIT_EXPORT NSString *NSStrikethroughStyleAttributeName;
 APPKIT_EXPORT NSString *NSStrokeColorAttributeName;
 APPKIT_EXPORT NSString *NSStrokeWidthAttributeName;
 APPKIT_EXPORT NSString *NSSuperscriptAttributeName;
@@ -77,6 +77,14 @@ APPKIT_EXPORT NSString *NSToolTipAttributeName;
 APPKIT_EXPORT NSString *NSUnderlineColorAttributeName;
 APPKIT_EXPORT NSString *NSUnderlineStyleAttributeName;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_8, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSTextAlternativesAttributeName;
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+APPKIT_EXPORT NSString *NSWritingDirectionAttributeName;
+#endif
+
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_2, GS_API_LATEST)
 APPKIT_EXPORT NSString *NSGlyphInfoAttributeName;
 #endif
@@ -118,6 +126,8 @@ APPKIT_EXPORT NSString *NSMacSimpleTextDocumentType;
 APPKIT_EXPORT NSString *NSHTMLTextDocumentType;
 APPKIT_EXPORT NSString *NSDocFormatTextDocumentType;
 APPKIT_EXPORT NSString *NSWordMLTextDocumentType;
+APPKIT_EXPORT NSString *NSOfficeOpenXMLTextDocumentType;
+APPKIT_EXPORT NSString *NSOpenDocumentTextDocumentType;
 
 // for HTML export
 
@@ -141,6 +151,9 @@ APPKIT_EXPORT NSString *NSWebResourceLoadDelegateDocumentOption;
 
 APPKIT_EXPORT NSString *NSCharacterShapeAttributeName;
 APPKIT_EXPORT const unsigned NSUnderlineByWordMask;
+APPKIT_EXPORT NSString *NSSpellingStateAttributeName;
+APPKIT_EXPORT const unsigned NSSpellingStateSpellingFlag;
+APPKIT_EXPORT const unsigned NSSpellingStateGrammarFlag;
 
 // readFrom... attributes
 
@@ -157,6 +170,9 @@ APPKIT_EXPORT NSString *NSWebPreferencesDocumentOption;
 APPKIT_EXPORT NSString *NSWebResourceLoadDelegateDocumentOption;
 APPKIT_EXPORT NSString *NSTextSizeMultiplierDocumentOption;
 
+// Private Attributes
+APPKIT_EXPORT NSString *NSTextInsertionUndoableAttributeName;
+
 /* Currently supported values for NSUnderlineStyleAttributeName.  */
 enum _NSUnderlineStyle
 {
@@ -186,6 +202,14 @@ enum
 };
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_11, GS_API_LATEST)
+typedef NSInteger NSWritingDirectionFormatType;
+enum {
+  NSWritingDirectionEmbedding = (0 << 1),
+  NSWritingDirectionOverride = (1 << 1)
+};
+#endif
+
 @interface NSAttributedString (AppKit)
 - (BOOL) containsAttachments;
 - (NSDictionary*) fontAttributesInRange: (NSRange)range;
