@@ -29,7 +29,7 @@
 
 #ifndef _GNUstep_H_NSBrowser
 #define _GNUstep_H_NSBrowser
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSControl.h>
 
@@ -37,12 +37,13 @@
 @class NSArray;
 @class NSIndexPath;
 @class NSIndexSet;
+@class NSMutableDictionary;
 
 @class NSCell;
 @class NSEvent;
 @class NSMatrix;
 @class NSScroller;
-//@class NSBox;
+@class NSViewController;
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
 enum _NSBrowserColumnResizingType
@@ -54,6 +55,7 @@ enum _NSBrowserColumnResizingType
 typedef NSUInteger NSBrowserColumnResizingType;
 #endif
 
+APPKIT_EXPORT_CLASS
 @interface NSBrowser : NSControl <NSCoding>
 {
   // Attributes
@@ -61,7 +63,6 @@ typedef NSUInteger NSBrowserColumnResizingType;
   Class _browserMatrixClass;
   NSString *_pathSeparator;
   
-  //NSBox *_horizontalScrollerBox;
   NSScroller *_horizontalScroller;
   NSTimeInterval _lastKeyPressed;
   NSString *_charBuffer;
@@ -98,6 +99,9 @@ typedef NSUInteger NSBrowserColumnResizingType;
   int _lastVisibleColumn;
   NSString *_columnsAutosaveName;
   NSBrowserColumnResizingType _columnResizing;
+
+  BOOL _itemBasedDelegate;
+  NSMutableDictionary *_columnDictionary;
 }
 
 //
@@ -315,7 +319,13 @@ typedef NSUInteger NSBrowserColumnResizingType;
 //
 // Methods Implemented by the Delegate 
 //
+@protocol NSBrowserDelegate <NSObject>
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST) && GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
 @interface NSObject (NSBrowserDelegate)
+#endif
 
 - (void) browser: (NSBrowser *)sender createRowsForColumn: (NSInteger)column
   inMatrix: (NSMatrix *)matrix;
@@ -348,6 +358,31 @@ canDragRowsWithIndexes: (NSIndexSet *)rowIndexes
         inColumn: (NSInteger)column
        withEvent: (NSEvent *)event;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (NSInteger) browser: (NSBrowser *)browser
+numberOfChildrenOfItem: (id)item;
+- (id) browser: (NSBrowser *)browser
+         child: (NSInteger)index
+        ofItem: (id)item;
+- (BOOL) browser: (NSBrowser *)browser
+      isLeafItem: (id)item;
+- (BOOL) browser: (NSBrowser *)browser
+  shouldEditItem: (id)item;
+- (id) browser: (NSBrowser *)browser
+objectValueForItem: (id)item;
+- (id) browser: (NSBrowser *)browser
+setObjectValue: (id)object
+       forItem: (id)item;
+- (id) rootItemForBrowser: (NSBrowser *)browser;
+- (NSViewController *) browser: (NSBrowser *)browser
+previewViewControllerForLeafItem: (id)item;
+- (NSViewController *) browser: (NSBrowser *)browser
+   headerViewControllerForItem: (id)item;
+- (void) browser: (NSBrowser *)browser
+didChangeLastColumn: (NSInteger)oldLastColumn
+        toColumn: (NSInteger)column;
+#endif
+
 @end
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
