@@ -29,10 +29,11 @@
 
 #ifndef _GNUstep_H_NSFontPanel
 #define _GNUstep_H_NSFontPanel
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSPanel.h>
 #import <AppKit/NSFontManager.h>
+#import <AppKit/NSTextField.h> // needed for NSTextFieldDelegate
 
 @class NSFont;
 @class NSView;
@@ -55,7 +56,8 @@ enum {
   NSFPSizeBrowser
 };
 
-@interface NSFontPanel : NSPanel <NSCoding>
+APPKIT_EXPORT_CLASS
+@interface NSFontPanel : NSPanel <NSTextFieldDelegate>
 {
   // Attributes
   NSFont *_panelFont;
@@ -63,8 +65,8 @@ enum {
   BOOL _preview;
 
   // store currently selected information
-  NSMutableArray *_familyList;
-  NSMutableArray *_faceList;
+  NSArray *_familyList;
+  NSArray *_faceList;
   int _family;
   int _face;
   NSFontTraitMask _traits;
