@@ -29,12 +29,12 @@
 
 #ifndef _GNUstep_H_NSHelpPanel
 #define _GNUstep_H_NSHelpPanel
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
-#if	OS_API_VERSION(GS_API_OPENSTEP,GS_API_MACOSX) || GS_API_VERSION(GS_API_NONE, GS_API_LATEST)
+#if OS_API_VERSION(GS_API_OPENSTEP,GS_API_MACOSX) || GS_API_VERSION(GS_API_NONE, GS_API_LATEST)
 
-#include <AppKit/NSApplication.h>
-#include <AppKit/NSPanel.h>
+#import <AppKit/NSApplication.h>
+#import <AppKit/NSPanel.h>
 
 @class NSString;
 
@@ -42,7 +42,8 @@
 - (void) orderFrontHelpPanel: (id)sender;
 @end
 
-@interface NSHelpPanel : NSPanel <NSCoding>
+APPKIT_EXPORT_CLASS
+@interface NSHelpPanel : NSPanel
 {
   // Attributes
 }
@@ -82,12 +83,6 @@
 //
 - (void) print: (id)sender;
 
-//
-// NSCoding protocol
-//
-- (void) encodeWithCoder: (NSCoder *)aCoder;
-- (id) initWithCoder: (NSCoder *)aDecoder;
-
 @end
 
 #endif // !GS_API_MACOSX
