@@ -30,13 +30,14 @@
 
 #ifndef _GNUstep_H_NSTableColumn
 #define _GNUstep_H_NSTableColumn
+#import <AppKit/AppKitDefines.h>
 
 #import <Foundation/NSObject.h>
-#import <AppKit/AppKitDefines.h>
 
 @class NSSortDescriptor;
 @class NSCell;
 @class NSTableView;
+@class NSMutableArray;
 
 // TODO: Finish to implement hidden, header tool tip and resizing mask 
 // and update the archiving code to support them.
@@ -56,6 +57,7 @@ enum {
   /** Allow the user to resize the column manually. */
 };
 
+APPKIT_EXPORT_CLASS
 @interface NSTableColumn : NSObject <NSCoding>
 {
   id _identifier;
@@ -71,6 +73,7 @@ enum {
   NSCell *_dataCell;
   NSString *_headerToolTip;
   NSSortDescriptor *_sortDescriptorPrototype;
+  NSMutableArray *_prototypeCellViews;
 }
 /* 
  * Initializing an NSTableColumn instance 
@@ -89,12 +92,12 @@ enum {
 /*
  * Controlling size & visibility
  */
-- (void) setWidth: (float)newWidth;
-- (float) width; 
-- (void) setMinWidth: (float)minWidth;
-- (float) minWidth; 
-- (void) setMaxWidth: (float)maxWidth;
-- (float) maxWidth; 
+- (void) setWidth: (CGFloat)newWidth;
+- (CGFloat) width; 
+- (void) setMinWidth: (CGFloat)minWidth;
+- (CGFloat) minWidth; 
+- (void) setMaxWidth: (CGFloat)maxWidth;
+- (CGFloat) maxWidth; 
 - (void) setResizable: (BOOL)flag;
 - (BOOL) isResizable;
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_4, GS_API_LATEST)
@@ -122,7 +125,7 @@ enum {
 #endif
 - (void) setDataCell: (NSCell *)aCell; 
 - (NSCell *) dataCell;
-- (NSCell *) dataCellForRow: (int)row;
+- (NSCell *) dataCellForRow: (NSInteger)row;
 /*
  * Sorting
  */
@@ -130,6 +133,13 @@ enum {
 - (void) setSortDescriptorPrototype: (NSSortDescriptor *)aSortDescriptor;
 - (NSSortDescriptor *) sortDescriptorPrototype;
 #endif
+/*
+ * Title
+ */
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_10, GS_API_LATEST)
+- (void) setTitle: (NSString *)title;
+- (NSString *) title;
+#endif
 @end
 
 /* Notifications */
