@@ -102,6 +102,15 @@ typedef enum _NSTableViewRowSizeStyle
 } NSTableViewRowSizeStyle;
 #endif
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+typedef enum _NSTableViewDraggingDestinationFeedbackStyle
+{
+  NSTableViewDraggingDestinationFeedbackStyleNone = 0,
+  NSTableViewDraggingDestinationFeedbackStyleRegular,
+  NSTableViewDraggingDestinationFeedbackStyleSourceList,
+  NSTableViewDraggingDestinationFeedbackStyleGap,
+} NSTableViewDraggingDestinationFeedbackStyle;
+#endif
 
 APPKIT_EXPORT_CLASS
 @interface NSTableView : NSControl <NSUserInterfaceValidations>
@@ -195,6 +204,9 @@ APPKIT_EXPORT_CLASS
   NSMapTable *_pathsToViews;
   NSMutableDictionary *_registeredNibs;
   NSMutableDictionary *_registeredViews;
+
+  /* NSTableRowView support */
+  NSMutableDictionary *_rowViews;
 }
 
 /* Data Source */
@@ -402,6 +414,8 @@ APPKIT_EXPORT_CLASS
 - (void) removeRowsAtIndexes: (NSIndexSet*)indexes withAnimation: (NSTableViewAnimationOptions)animationOptions;
 - (NSInteger) rowForView: (NSView*)view;
 - (NSView *) makeViewWithIdentifier: (NSUserInterfaceItemIdentifier)identifier owner: (id)owner;
+- (NSTableRowView *) rowViewAtRow: (NSInteger)row makeIfNecessary: (BOOL)flag;
+- (NSView *) viewAtColumn: (NSInteger)column row: (NSInteger)row makeIfNecessary: (BOOL)flag;
 #endif
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_8, GS_API_LATEST)
