@@ -49,6 +49,39 @@
   // should do something...
 }
 
++ (BOOL) canReadData: (NSData *)theData
+{
+  char *header = calloc(1024, sizeof(char));
+
+  if (header != NULL)
+    {
+      [theData getBytes: header
+                 length: 1024];
+
+      if (strncmp("bplist00",header,8) == 0)
+        {
+          free(header);
+          return YES;
+        }
+      else
+        {
+          NSString *hdr = [[NSString alloc] initWithBytes: header
+                                                   length: 1024
+                                                 encoding: NSUTF8StringEncoding];
+          AUTORELEASE(hdr);
+          if ([hdr containsString: @"NSKeyedArchiver"])
+            {
+              free(header);
+              return YES;
+            }
+        }
+
+      free(header);
+    }
+
+  return NO;
+}
+
 + (NSString *)type
 {
   return @"nib";
