@@ -35,7 +35,7 @@
 #import <Foundation/NSRunLoop.h>
 #import <Foundation/NSThread.h>
 #import <Foundation/NSValue.h>
-#import <GNUstepBase/GSLock.h>
+#import <Foundation/NSLock.h>
 
 #import "AppKit/NSAnimation.h"
 #import "AppKit/NSApplication.h"
@@ -78,14 +78,6 @@ _GSBezierEval(_GSBezierDesc *b, float t)
   return b->a[0] + t * (b->a[1] + t * (b->a[2] + t * b->a[3]));
 }
 
-static inline float 
-_GSBezierDerivEval(_GSBezierDesc *b, float t)
-{
-  if (!b->areCoefficientsComputed)
-    _GSBezierComputeCoefficients(b);
-  return b->a[1] + t * (2.0 * b->a[2] + t * 3.0 * b->a[3]);
-}
-
 static inline void 
 _GSRationalBezierComputeBezierDesc(_GSRationalBezierDesc *rb)
 {
@@ -106,18 +98,6 @@ _GSRationalBezierEval(_GSRationalBezierDesc *rb, float t)
   return _GSBezierEval(&(rb->n), t) / _GSBezierEval(&(rb->d), t);
 }
 
-static inline float
-_GSRationalBezierDerivEval(_GSRationalBezierDesc *rb, float t)
-{
-  float h;
-  if (!rb->areBezierDescComputed)
-    _GSRationalBezierComputeBezierDesc(rb);
-  h = _GSBezierEval(&(rb->d), t);
-  return (_GSBezierDerivEval(&(rb->n), t) * h 
-          - _GSBezierEval   (&(rb->n), t) * _GSBezierDerivEval(&(rb->d), t))
-    / (h*h);
-}
-
 static
 _NSAnimationCurveDesc _gs_animationCurveDesc[] =
 {
@@ -438,7 +418,7 @@ nsanimation_progressMarkSorter(NSAnimationProgress first, NSAnimationProgress se
         (BOOL (*)(id,SEL,NSAnimation*)) NULL;
       
       _isThreaded = NO;
-      _isAnimatingLock = [GSLazyRecursiveLock new];
+      _isAnimatingLock = [NSRecursiveLock new];
     }
   return self;
 }
@@ -450,7 +430,7 @@ nsanimation_progressMarkSorter(NSAnimationProgress first, NSAnimationProgress se
   c->_progressMarks = GSIArrayCopyWithZone(_progressMarks, zone);
   c->_animator = nil;
   c->_isANewAnimatorNeeded = YES;
-  c->_isAnimatingLock = [GSLazyRecursiveLock new];
+  c->_isAnimatingLock = [NSRecursiveLock new];
   return c;
 }
 
@@ -1012,7 +992,7 @@ nsanimation_progressMarkSorter(NSAnimationProgress first, NSAnimationProgress se
   _NSANIMATION_UNLOCK;
 }
 
-- (void) animatorStep: (NSTimeInterval) elapsedTime;
+- (void) animatorStep: (NSTimeInterval) elapsedTime
 {
   NSAnimationProgress progress;
   _NSANIMATION_LOCKING_SETUP;
@@ -1220,7 +1200,7 @@ nsanimation_progressMarkSorter(NSAnimationProgress first, NSAnimationProgress se
   _NSANIMATION_UNLOCK;
 }
 
-- (float) actualFrameRate;
+- (float) actualFrameRate
 { 
   float r;
   _NSANIMATION_LOCKING_SETUP;
