@@ -29,7 +29,7 @@
 #ifndef _NSBitmapImageRep_JPEG_H_include
 #define _NSBitmapImageRep_JPEG_H_include
 
-#include "AppKit/NSBitmapImageRep.h"
+#import "AppKit/NSBitmapImageRep.h"
 
 
 @interface NSBitmapImageRep (JPEGReading)
