@@ -3,7 +3,7 @@
    <abstract>Simple box view that can display a border and title
    </abstract>
 
-   Copyright (C) 1996-2015 Free Software Foundation, Inc.
+   Copyright (C) 1996-2024 Free Software Foundation, Inc.
 
    Author:  Scott Christley <scottc@net-community.com>
    Date: 1996
@@ -41,6 +41,7 @@
 #import "AppKit/NSTextFieldCell.h"
 #import "AppKit/NSWindow.h"
 #import "GNUstepGUI/GSTheme.h"
+#import "GSGuiPrivate.h"
 
 #include <math.h>
 
@@ -464,18 +465,7 @@
 
 - (BOOL) isOpaque
 {
-  // FIXME: Depends on theme; if always returning NO is a performance hit
-  // we can check if GSTheme is going to draw an old-style opaque box
-  // or not.
-  return NO;
-  // if (_box_type == NSBoxCustom)
-  //   {
-  //     return !_transparent;
-  //   }
-  // else
-  //   {
-  //     return YES;
-  //   }
+  return [[GSTheme theme] isBoxOpaque: self];
 }
 
 - (NSColor*) fillColor
@@ -629,13 +619,31 @@
           [self setContentView: cv];
           RELEASE(cv);
         }
+
+      [self setBorderColor: [NSColor clearColor]];
+      if ([aDecoder containsValueForKey: @"NSBorderColor2"])
+        {
+          NSColor *color = [aDecoder decodeObjectForKey: @"NSBorderColor2"];
+          if (color != nil)
+            [self setBorderColor:color];
+        }
+
+      [self setFillColor:[NSColor clearColor]];
+      if ([aDecoder containsValueForKey: @"NSFillColor2"])
+        {
+          NSColor *color = [aDecoder decodeObjectForKey:@"NSFillColor2"];
+          if (color != nil)
+            [self setFillColor:color];
+        }
     }
   else
     {
+      NSInteger tempInt;
+
         [aDecoder decodeValueOfObjCType: @encode(id) at: &_cell];
         _offsets = [aDecoder decodeSize];
-        [aDecoder decodeValueOfObjCType: @encode(int)
-                                     at: &_border_type];
+	decode_NSInteger(aDecoder, &tempInt);
+	_border_type = tempInt;
         [aDecoder decodeValueOfObjCType: @encode(int) 
                                      at: &_title_position];
 
