@@ -2,7 +2,7 @@
 
    <abstract>The image cell class</abstract>
 
-   Copyright (C) 1999, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2005-2022 Free Software Foundation, Inc.
 
    Author: Jonathan Gapen <jagapen@smithlab.chem.wisc.edu>
    Date: 1999
@@ -51,7 +51,7 @@
 {
   if (self == [NSImageCell class])
     {
-      [self setVersion: 1];
+      [self setVersion: 2];
     }
 }
 
@@ -63,16 +63,26 @@
   return [self initImageCell: nil];
 }
 
-- (void) setImage:(NSImage *)anImage
+- (id) initImageCell: (NSImage*)anImage
 {
-  [super setImage:anImage];
+  self = [super initImageCell: anImage];
+  if (self != nil)
+    {
+      [self setRefusesFirstResponder: YES];
+    }
+  return self;
+}
+
+- (void) setImage: (NSImage *)anImage
+{
+  [super setImage: anImage];
   if (anImage)
     _original_image_size = [anImage size];
   else
     _original_image_size = NSMakeSize(1,1);
 }
 
-- (void)setObjectValue:(id)object
+- (void) setObjectValue: (id)object
 {
   if ((object == nil) || ([object isKindOfClass:[NSImage class]]))
     {
@@ -344,7 +354,13 @@ yBottomInRect(NSSize innerSize, NSRect outerRect, BOOL flipped)
       else
 	{
           NSInteger tmp;
-
+          NSUInteger version = [aDecoder versionForClassName: @"NSImageCell"];
+          
+          if (version == 1)
+            {
+              [self setRefusesFirstResponder: YES];
+            }
+          
           decode_NSInteger(aDecoder, &tmp);
           _imageAlignment = tmp;
           decode_NSInteger(aDecoder, &tmp);
