@@ -24,7 +24,7 @@
    Boston, MA 02110-1301, USA.
 */ 
 
-#include "AppKit/NSInputServer.h"
+#import "AppKit/NSInputServer.h"
 
 @implementation NSInputServer
 
