@@ -40,7 +40,7 @@
 #import <Foundation/NSMapTable.h>
 #import <Foundation/NSValue.h>
 #import <Foundation/NSValueTransformer.h>
-#import <GNUstepBase/GSLock.h>
+#import <Foundation/NSLock.h>
 
 #import "AppKit/NSKeyValueBinding.h"
 #import "GSBindingHelpers.h"
@@ -145,7 +145,7 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
 {
   if (self == [GSKeyValueBinding class])
     {
-      bindingLock = [GSLazyRecursiveLock new];
+      bindingLock = [NSRecursiveLock new];
       classTable = NSCreateMapTable(NSNonOwnedPointerMapKeyCallBacks,
           NSObjectMapValueCallBacks, 128);
       objectTable = NSCreateMapTable(NSNonRetainedObjectMapKeyCallBacks,
@@ -192,8 +192,11 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
   if (!objectTable)
     return nil;
 
+  NSDebugLLog(@"NSBinding", @"+++ called with %@, %@", binding, anObject);
   [bindingLock lock];
   bindings = (NSMutableDictionary *)NSMapGet(objectTable, (void *)anObject);
+
+  NSDebugLLog(@"NSBinding", @"+++ Bindings found for %@ => %@", anObject, bindings);
   if (bindings != nil)
     {
       theBinding = (GSKeyValueBinding*)[bindings objectForKey: binding];
@@ -321,6 +324,11 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
   [super dealloc];
 }
 
+- (id) observedObject
+{
+  return [info objectForKey: NSObservedObjectKey];
+}
+
 - (id) destinationValue
 {
   id newValue;
@@ -361,7 +369,9 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
   keyPath = [info objectForKey: NSObservedKeyPathKey];
   dest = [info objectForKey: NSObservedObjectKey];
   NSDebugLLog(@"NSBinding", @"reverseSetValue: keyPath %@, dest %@ value %@", keyPath, dest, value);
+  inReverseSet = YES;
   [dest setValue: value forKeyPath: keyPath];
+  inReverseSet = NO;
 }
 
 - (void) reverseSetValueFor: (NSString *)binding
@@ -378,6 +388,11 @@ void GSBindingInvokeAction(NSString *targetKey, NSString *argumentKey,
   NSDictionary *options;
   id newValue;
 
+  if (inReverseSet)
+    {
+      return;
+    }
+
   if (change != nil)
     {
       options = [info objectForKey: NSOptionsKey];
