@@ -27,16 +27,16 @@
 */ 
 
 #include "config.h"
-#include <Foundation/NSCoder.h>
-#include <Foundation/NSDebug.h>
-#include <Foundation/NSInvocation.h>
-#include "AppKit/NSResponder.h"
-#include "AppKit/NSApplication.h"
-#include "AppKit/NSMenu.h"
-#include "AppKit/NSEvent.h"
-#include "AppKit/NSGraphics.h"
-#include "AppKit/NSHelpManager.h"
-#include "AppKit/NSInputManager.h"
+#import <Foundation/NSCoder.h>
+#import <Foundation/NSDebug.h>
+#import <Foundation/NSInvocation.h>
+#import "AppKit/NSResponder.h"
+#import "AppKit/NSApplication.h"
+#import "AppKit/NSMenu.h"
+#import "AppKit/NSEvent.h"
+#import "AppKit/NSGraphics.h"
+#import "AppKit/NSHelpManager.h"
+#import "AppKit/NSInputManager.h"
 
 @implementation NSResponder
 
@@ -280,7 +280,7 @@
 - (void) noResponderFor: (SEL)eventSelector
 {
   /* Only beep for key down events */
-  if (sel_eq(eventSelector, @selector(keyDown:)))
+  if (sel_isEqual(eventSelector, @selector(keyDown:)))
     NSBeep();
 }
 
@@ -357,8 +357,7 @@
     }
   else
     {
-      [aCoder encodeValueOfObjCType: @encode(NSInterfaceStyle)
-	      at: &_interface_style];
+      [aCoder encodeValueOfObjCType: @encode(int) at: &_interface_style];
       [aCoder encodeObject: _menu];
     }
 }
@@ -386,8 +385,7 @@
     }
   else
     {
-      [aDecoder decodeValueOfObjCType: @encode(NSInterfaceStyle)
-		at: &_interface_style];
+      [aDecoder decodeValueOfObjCType: @encode(int) at: &_interface_style];
       obj = [aDecoder decodeObject];
     }
 
