@@ -233,6 +233,7 @@ setPath(NSBrowser *browser, NSString *path)
   [_browser setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];
   [_browser setTag: NSFileHandlingPanelBrowser];
   [_browser setAction: @selector(_selectText:)];
+  [_browser setDoubleAction: @selector(_doubleClick:)];
   [_browser setTarget: self];
   [_browser setMinColumnWidth: 140];
   [_topView addSubview: _browser];
@@ -346,9 +347,6 @@ setPath(NSBrowser *browser, NSString *path)
   [self setDefaultButtonCell: [_okButton cell]];
   [_okButton release];
 
-  [_browser setDoubleAction: @selector(performClick:)];
-  [_browser setTarget: _okButton];
-
   r = NSMakeRect (8, 261, 48, 48);
   image = [[NSApplication sharedApplication] applicationIconImage];
   imageView = [[NSImageView alloc] initWithFrame: r];
@@ -508,6 +506,11 @@ setPath(NSBrowser *browser, NSString *path)
     }
 }
 
+- (void) _doubleClick: (id)sender
+{
+  [_okButton performClick: sender];
+}
+
 - (void) _selectText: (id)sender
 {
   [self _selectTextInColumn:[_browser selectedColumn]];
@@ -574,7 +577,7 @@ selectCellWithString: (NSString*)title
   else
     {
       ASSIGN (_directory, [path stringByAppendingPathComponent: title]);
-      ASSIGN (_fullFileName, nil);
+      DESTROY (_fullFileName);
     }
 
   [self _selectTextInColumn:column];
