@@ -28,7 +28,7 @@
    If not, see <http://www.gnu.org/licenses/> or write to the 
    Free Software Foundation, 51 Franklin Street, Fifth Floor, 
    Boston, MA 02110-1301, USA.
-*/ 
+*/
 
 #import "config.h"
 
@@ -131,6 +131,7 @@ static NSImage	*multipleFiles = nil;
 static NSImage	*unknownApplication = nil;
 static NSImage	*unknownTool = nil;
 
+static NSLock   *classLock = nil;
 static NSLock   *mlock = nil;
 
 static NSString	*GSWorkspaceNotification = @"GSWorkspaceNotification";
@@ -598,26 +599,22 @@ static NSDictionary		*urlPreferences = nil;
 {
   if (self == [NSWorkspace class])
     {
-      static BOOL	beenHere = NO;
-      NSFileManager	*mgr = [NSFileManager defaultManager];
-      NSString		*service;
-      NSData		*data;
-      NSDictionary	*dict;
-
       [self setVersion: 1];
-
-      [gnustep_global_lock lock];
-      if (beenHere == YES)
+      if (classLock)
 	{
-	  [gnustep_global_lock unlock];
 	  return;
 	}
-
-      beenHere = YES;
+      classLock = [NSLock new];
       mlock = [NSLock new];
 
       NS_DURING
 	{
+	  NSFileManager	*mgr = [NSFileManager defaultManager];
+	  NSString	*service;
+	  NSData	*data;
+	  NSDictionary	*dict;
+
+
 	  service = [[NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, 
 	    NSUserDomainMask, YES) objectAtIndex: 0]
 	    stringByAppendingPathComponent: @"Services"];
@@ -675,12 +672,9 @@ static NSDictionary		*urlPreferences = nil;
 	}
       NS_HANDLER
 	{
-	  [gnustep_global_lock unlock];
 	  [localException raise];
 	}
       NS_ENDHANDLER
-
-      [gnustep_global_lock unlock];
     }
 }
 
@@ -698,14 +692,14 @@ static NSDictionary		*urlPreferences = nil;
 {
   if (sharedWorkspace == nil)
     {
-      [gnustep_global_lock lock];
+      [classLock lock];
       if (sharedWorkspace == nil)
 	{
 	  sharedWorkspace =
 		(NSWorkspace*)NSAllocateObject(self, 0, NSDefaultMallocZone());
 	  [sharedWorkspace init];
 	}
-      [gnustep_global_lock unlock];
+      [classLock unlock];
     }
   return sharedWorkspace;
 }
@@ -800,10 +794,10 @@ static NSDictionary		*urlPreferences = nil;
     }
 
   if (sysDir != nil)
-    [folderPathIconDict setObject: @"GSFolder" forKey: sysDir];
+    [folderPathIconDict setObject: @"GSFolder" forKey: [sysDir stringByResolvingSymlinksInPath]];
 
   [folderPathIconDict setObject: @"HomeDirectory"
-    forKey: NSHomeDirectory()];
+			 forKey: [NSHomeDirectory() stringByResolvingSymlinksInPath]];
 
   /* it would be nice to use different root icons... */
   [folderPathIconDict setObject: @"Root_PC" forKey: NSOpenStepRootDirectory()];
@@ -811,42 +805,42 @@ static NSDictionary		*urlPreferences = nil;
   for (i = 0; i < [libraryDirs count]; i++)
     {
       [folderPathIconDict setObject: @"LibraryFolder"
-	forKey: [libraryDirs objectAtIndex: i]];
+	forKey: [[libraryDirs objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [appDirs count]; i++)
     {
       [folderPathIconDict setObject: @"ApplicationFolder"
-	forKey: [appDirs objectAtIndex: i]];
+	forKey: [[appDirs objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [documentDir count]; i++)
     {
       [folderPathIconDict setObject: @"DocsFolder"
-	forKey: [documentDir objectAtIndex: i]];
+	forKey: [[documentDir objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [downloadDir count]; i++)
     {
       [folderPathIconDict setObject: @"DownloadFolder"
-	forKey: [downloadDir objectAtIndex: i]];
+	forKey: [[downloadDir objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [desktopDir count]; i++)
     {
       [folderPathIconDict setObject: @"Desktop"
-	forKey: [desktopDir objectAtIndex: i]];
+	forKey: [[desktopDir objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [imgDir count]; i++)
     {
       [folderPathIconDict setObject: @"ImageFolder"
-	forKey: [imgDir objectAtIndex: i]];
+	forKey: [[imgDir objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [musicDir count]; i++)
     {
       [folderPathIconDict setObject: @"MusicFolder"
-	forKey: [musicDir objectAtIndex: i]];
+	forKey: [[musicDir objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   for (i = 0; i < [videoDir count]; i++)
     {
       [folderPathIconDict setObject: @"VideoFolder"
-	forKey: [videoDir objectAtIndex: i]];
+	forKey: [[videoDir objectAtIndex: i] stringByResolvingSymlinksInPath]];
     }
   folderIconCache = [[NSMutableDictionary alloc] init];
 
@@ -1520,13 +1514,13 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
   if ([fileType isEqual: NSFileTypeDirectory] == YES)
     {
       NSString *iconPath = nil;
-      
+
       if ([pathExtension isEqualToString: @"app"]
 	|| [pathExtension isEqualToString: @"debug"]
 	|| [pathExtension isEqualToString: @"profile"])
 	{
 	  image = [self appIconForApp: fullPath];
-	  
+
 	  if (image == nil)
 	    {
 	      /*
@@ -1746,6 +1740,13 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
     {
       path = [[NSTask launchPathForTool: @"make_services"] retain];
     }
+
+  if (path == nil)
+    {
+      [NSException raise: NSInternalInconsistencyException
+	           format: @"Unable to find the make_services tool.\n"];
+    }
+
   task = [NSTask launchedTaskWithLaunchPath: path
 				  arguments: nil];
   if (task != nil)
