@@ -2,7 +2,7 @@
    NeXTstep/ OPENSTEP 'make_services' tool.  In addition it builds a list of
    applications and services-bundles found in the standard directories.
 
-   Copyright (C) 1998 Free Software Foundation, Inc.
+   Copyright (C) 1998-2013 Free Software Foundation, Inc.
 
    Written by:  Richard Frith-Macdonald <richard@brainstorm.co.uk>
    Created: November 1998
@@ -50,7 +50,7 @@ static NSMutableDictionary *validateService(NSDictionary *service, NSString* pat
 static NSString		*appsName = @".GNUstepAppList";
 static NSString		*cacheName = @".GNUstepServices";
 
-static	int verbose = 0;
+static	int verbose = 1;
 static	NSMutableDictionary	*serviceMap;
 static	NSMutableArray		*filterList;
 static	NSMutableSet		*filterSet;
@@ -64,28 +64,23 @@ static Class aClass;
 static Class dClass;
 static Class sClass;
 
-static BOOL CheckDirectory(NSString *path)
+static BOOL CheckDirectory(NSString *path, NSError **error)
 {
   NSFileManager	*mgr;
   BOOL		isDir;
 
   mgr = [NSFileManager defaultManager];
-  if (([mgr fileExistsAtPath: path isDirectory: &isDir] && isDir) == 0)
+  if ([mgr fileExistsAtPath: path isDirectory: &isDir] && isDir)
     {
-      NSString	*parent;
-
-      parent = [path stringByDeletingLastPathComponent];
-      if ([parent length] < [path length]
-	&& CheckDirectory([parent stringByDeletingLastPathComponent]) == NO)
-	{
-	  return NO;
-	}
-      if ([mgr createDirectoryAtPath: path attributes: nil] == NO)
-	{
-	  return NO;
-	}
+      return YES;
+    }
+  else
+    {
+      return [mgr createDirectoryAtPath: path
+            withIntermediateDirectories: YES
+                             attributes: nil
+                                  error: error];
     }
-  return YES;
 }
 
 int
@@ -104,6 +99,7 @@ main(int argc, char** argv, char **env_c)
   NSDictionary		*oldMap;
   NSEnumerator		*enumerator;
   NSString		*path;
+  NSError *error;
 
 #ifdef GS_PASS_ARGUMENTS
   [NSProcessInfo initializeWithArguments:argv count:argc environment:env_c];
@@ -162,7 +158,6 @@ main(int argc, char** argv, char **env_c)
 	}
       if ([[args objectAtIndex: index] isEqual: @"--test"])
 	{
-	  verbose = YES;
 	  while (++index < [args count])
 	    {
 	      NSString		*file = [args objectAtIndex: index];
@@ -199,10 +194,10 @@ main(int argc, char** argv, char **env_c)
   usrRoot = [NSSearchPathForDirectoriesInDomains(NSLibraryDirectory,
     NSUserDomainMask, YES) lastObject];
   usrRoot = [usrRoot stringByAppendingPathComponent: @"Services"];
-  if (CheckDirectory(usrRoot) == NO)
+  if (!CheckDirectory(usrRoot, &error))
     {
       if (verbose > 0)
-	NSLog(@"couldn't create %@", usrRoot);
+	NSLog(@"couldn't create %@ error: %@", usrRoot, error);
       [pool drain];
       exit(EXIT_FAILURE);
     }
@@ -1080,17 +1075,46 @@ validateService(NSDictionary *service, NSString *path, unsigned pos)
       NSArray		*ret;
       BOOL		notPresent = NO;
 
+      snd = [result objectForKey: @"NSSendTypes"];
+      ret = [result objectForKey: @"NSReturnTypes"];
       str = [result objectForKey: @"NSInputMechanism"];
       if (str != nil)
 	{
-	  if ([str isEqualToString: @"NSUnixStdio"] == NO
-	    && [str isEqualToString: @"NSMapFile"] == NO
-	    && [str isEqualToString: @"NSIdentity"] == NO)
-	  {
-	    if (verbose > 0)
-	      NSLog(@"NSServices entry %u bad input mechanism - %@", pos, path);
-	    return nil;
-	  }
+	  if ([str isEqualToString: @"NSUnixStdio"] == YES
+	    || [str isEqualToString: @"NSMapFile"] == YES)
+	    {
+	      unsigned	i = [snd count];
+
+	      while (i-- > 0)
+		{
+
+		  str = [snd objectAtIndex: i];
+		  /* For UNIX I/O or file mapping, the send type must be a
+		   * filename ... which means it must either be the generic
+		   * filenames pasteboard type, or one of the pasteboard
+		   * types corresponding to names for a particular file type.
+		   */
+		  if (NO == [str isEqual: @"NSFilenamesPboardType"]
+		    && NO == [str hasPrefix: @"NSTypedFilenamesPboardType:"])
+		    {
+		      if (verbose > 0)
+			{
+			  NSLog(@"NSServices entry %u bad NSSendTypes "
+			    @"(must be file names types) - %@",
+			    pos, path);
+			}
+		    }
+		}
+	    }
+	  else if ([str isEqualToString: @"NSIdentity"] == NO)
+	    {
+	      if (verbose > 0)
+		{
+		  NSLog(@"NSServices entry %u bad input mechanism - %@",
+		    pos, path);
+		}
+	      return nil;
+	    }
 	}
       else if ([result objectForKey: @"NSPortName"] == nil)
 	{
@@ -1099,8 +1123,6 @@ validateService(NSDictionary *service, NSString *path, unsigned pos)
 	  return nil;
 	}
 
-      snd = [result objectForKey: @"NSSendTypes"];
-      ret = [result objectForKey: @"NSReturnTypes"];
       if ([snd count] == 0 || [ret count] == 0)
 	{
 	  if (verbose > 0)
